==> azure_mgmt_network-0.2.0.crate: azure_mgmt_network-0.2.0/README.md <==
# azure_mgmt_network crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/network/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2021-05`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-2022-02-preview` has 603 operations from 3 API versions: `2018-10-01`, `2021-05-01`, `2022-02-01-preview`. Use crate feature `package-2022-02-preview` to enable. The operations will be in the `package_2022_02_preview` module.
- `package-2021-05-preview` has 603 operations from 3 API versions: `2018-10-01`, `2021-05-01`, `2021-05-01-preview`. Use crate feature `package-2021-05-preview` to enable. The operations will be in the `package_2021_05_preview` module.
- `package-2021-05` has 540 operations from 2 API versions: `2018-10-01`, `2021-05-01`. Use crate feature `package-2021-05` to enable. The operations will be in the `package_2021_05` module.
- `package-2021-03` has 529 operations from 2 API versions: `2018-10-01`, `2021-03-01`. Use crate feature `package-2021-03` to enable. The operations will be in the `package_2021_03` module.
- `package-2021-02` has 527 operations from 2 API versions: `2018-10-01`, `2021-02-01`. Use crate feature `package-2021-02` to enable. The operations will be in the `package_2021_02` module.
- `package-2020-11` has 522 operations from 2 API versions: `2018-10-01`, `2020-11-01`. Use crate feature `package-2020-11` to enable. The operations will be in the `package_2020_11` module.
- `package-2021-02-preview-only` has 65 operations from 1 API versions: `2021-02-01-preview`. Use crate feature `package-2021-02-preview-only` to enable. The operations will be in the `package_2021_02_preview_only` module.
- `package-2021-02-preview` has 594 operations from 3 API versions: `2018-10-01`, `2021-02-01-preview`, `2021-03-01`. Use crate feature `package-2021-02-preview` to enable. The operations will be in the `package_2021_02_preview` module.
- `package-2021-03-preview` has 533 operations from 3 API versions: `2018-10-01`, `2021-02-01`, `2021-03-01-preview`. Use crate feature `package-2021-03-preview` to enable. The operations will be in the `package_2021_03_preview` module.
- `package-2020-08` has 519 operations from 2 API versions: `2018-10-01`, `2020-08-01`. Use crate feature `package-2020-08` to enable. The operations will be in the `package_2020_08` module.
- `package-2020-07` has 513 operations from 2 API versions: `2018-10-01`, `2020-07-01`. Use crate feature `package-2020-07` to enable. The operations will be in the `package_2020_07` module.
- `package-2020-06` has 505 operations from 2 API versions: `2018-10-01`, `2020-06-01`. Use crate feature `package-2020-06` to enable. The operations will be in the `package_2020_06` module.
- `package-2020-05` has 485 operations from 2 API versions: `2018-10-01`, `2020-05-01`. Use crate feature `package-2020-05` to enable. The operations will be in the `package_2020_05` module.
- `package-2020-04` has 462 operations from 2 API versions: `2018-10-01`, `2020-04-01`. Use crate feature `package-2020-04` to enable. The operations will be in the `package_2020_04` module.
- `package-2020-03` has 456 operations from 2 API versions: `2018-10-01`, `2020-03-01`. Use crate feature `package-2020-03` to enable. The operations will be in the `package_2020_03` module.
- `package-2019-12` has 440 operations from 2 API versions: `2018-10-01`, `2019-12-01`. Use crate feature `package-2019-12` to enable. The operations will be in the `package_2019_12` module.
- `package-2019-11` has 434 operations from 2 API versions: `2018-10-01`, `2019-11-01`. Use crate feature `package-2019-11` to enable. The operations will be in the `package_2019_11` module.
- `package-2019-09` has 428 operations from 2 API versions: `2018-10-01`, `2019-09-01`. Use crate feature `package-2019-09` to enable. The operations will be in the `package_2019_09` module.
- `package-2019-08` has 415 operations from 2 API versions: `2018-10-01`, `2019-08-01`. Use crate feature `package-2019-08` to enable. The operations will be in the `package_2019_08` module.
- `package-2019-07` has 408 operations from 2 API versions: `2018-10-01`, `2019-07-01`. Use crate feature `package-2019-07` to enable. The operations will be in the `package_2019_07` module.
- `package-2019-06` has 394 operations from 2 API versions: `2017-03-30`, `2019-06-01`. Use crate feature `package-2019-06` to enable. The operations will be in the `package_2019_06` module.
- `package-2019-04` has 376 operations from 2 API versions: `2017-03-30`, `2019-04-01`. Use crate feature `package-2019-04` to enable. The operations will be in the `package_2019_04` module.
- `package-2019-02` has 354 operations from 2 API versions: `2017-03-30`, `2019-02-01`. Use crate feature `package-2019-02` to enable. The operations will be in the `package_2019_02` module.
- `package-2018-12` has 345 operations from 2 API versions: `2017-03-30`, `2018-12-01`. Use crate feature `package-2018-12` to enable. The operations will be in the `package_2018_12` module.
- `package-2018-12-only` has 332 operations from 1 API versions: `2018-12-01`. Use crate feature `package-2018-12-only` to enable. The operations will be in the `package_2018_12_only` module.
- `package-2018-11` has 337 operations from 2 API versions: `2017-03-30`, `2018-11-01`. Use crate feature `package-2018-11` to enable. The operations will be in the `package_2018_11` module.
- `package-2018-10` has 328 operations from 2 API versions: `2017-03-30`, `2018-10-01`. Use crate feature `package-2018-10` to enable. The operations will be in the `package_2018_10` module.
- `package-2018-08` has 327 operations from 2 API versions: `2017-03-30`, `2018-08-01`. Use crate feature `package-2018-08` to enable. The operations will be in the `package_2018_08` module.
- `package-2018-07` has 269 operations from 2 API versions: `2017-03-30`, `2018-07-01`. Use crate feature `package-2018-07` to enable. The operations will be in the `package_2018_07` module.
- `package-2018-06` has 254 operations from 2 API versions: `2017-03-30`, `2018-06-01`. Use crate feature `package-2018-06` to enable. The operations will be in the `package_2018_06` module.
- `package-2018-04` has 252 operations from 2 API versions: `2017-03-30`, `2018-04-01`. Use crate feature `package-2018-04` to enable. The operations will be in the `package_2018_04` module.
- `package-2018-02` has 216 operations from 2 API versions: `2017-03-30`, `2018-02-01`. Use crate feature `package-2018-02` to enable. The operations will be in the `package_2018_02` module.
- `package-2018-01` has 194 operations from 2 API versions: `2017-03-30`, `2018-01-01`. Use crate feature `package-2018-01` to enable. The operations will be in the `package_2018_01` module.
- `package-2018-01-only` has 186 operations from 1 API versions: `2018-01-01`. Use crate feature `package-2018-01-only` to enable. The operations will be in the `package_2018_01_only` module.
- `package-2017-11` has 194 operations from 2 API versions: `2017-03-30`, `2017-11-01`. Use crate feature `package-2017-11` to enable. The operations will be in the `package_2017_11` module.
- `package-2017-11-only` has 186 operations from 1 API versions: `2017-11-01`. Use crate feature `package-2017-11-only` to enable. The operations will be in the `package_2017_11_only` module.
- `package-2017-10` has 194 operations from 2 API versions: `2017-03-30`, `2017-10-01`. Use crate feature `package-2017-10` to enable. The operations will be in the `package_2017_10` module.
- `package-2017-10-only` has 186 operations from 1 API versions: `2017-10-01`. Use crate feature `package-2017-10-only` to enable. The operations will be in the `package_2017_10_only` module.
- `package-2017-09` has 187 operations from 2 API versions: `2017-03-30`, `2017-09-01`. Use crate feature `package-2017-09` to enable. The operations will be in the `package_2017_09` module.
- `package-2017-09-only` has 179 operations from 1 API versions: `2017-09-01`. Use crate feature `package-2017-09-only` to enable. The operations will be in the `package_2017_09_only` module.
- `package-2017-08` has 163 operations from 2 API versions: `2017-03-30`, `2017-08-01`. Use crate feature `package-2017-08` to enable. The operations will be in the `package_2017_08` module.
- `package-2017-06` has 162 operations from 2 API versions: `2017-03-30`, `2017-06-01`. Use crate feature `package-2017-06` to enable. The operations will be in the `package_2017_06` module.
- `package-2017-03` has 138 operations from 2 API versions: `2017-03-01`, `2017-03-30`. Use crate feature `package-2017-03` to enable. The operations will be in the `package_2017_03` module.
- `package-2017-03-only` has 132 operations from 1 API versions: `2017-03-01`. Use crate feature `package-2017-03-only` to enable. The operations will be in the `package_2017_03_only` module.
- `package-2017-03-30-only` has 8 operations from 2 API versions: `2017-03-30`, `2017-09-01`. Use crate feature `package-2017-03-30-only` to enable. The operations will be in the `package_2017_03_30_only` module.
- `package-2016-12` has 132 operations from 1 API versions: `2016-12-01`. Use crate feature `package-2016-12` to enable. The operations will be in the `package_2016_12` module.
- `package-2016-09` has 120 operations from 1 API versions: `2016-09-01`. Use crate feature `package-2016-09` to enable. The operations will be in the `package_2016_09` module.
- `package-2016-06` has 97 operations from 1 API versions: `2016-06-01`. Use crate feature `package-2016-06` to enable. The operations will be in the `package_2016_06` module.
- `package-2016-03` has 90 operations from 1 API versions: `2016-03-30`. Use crate feature `package-2016-03` to enable. The operations will be in the `package_2016_03` module.
- `package-2015-06split` has 88 operations from 1 API versions: `2015-06-15`. Use crate feature `package-2015-06split` to enable. The operations will be in the `package_2015_06split` module.
- `package-2015-05-preview` has 87 operations from 1 API versions: `2015-05-01-preview`. Use crate feature `package-2015-05-preview` to enable. The operations will be in the `package_2015_05_preview` module.
- `profile-hybrid-2020-09-01` has 112 operations from 1 API versions: `2018-11-01`. Use crate feature `profile-hybrid-2020-09-01` to enable. The operations will be in the `profile_hybrid_2020_09_01` module.

==> azure_mgmt_network-0.3.0.crate: azure_mgmt_network-0.3.0/README.md <==
# azure_mgmt_network crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/network/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2021-08`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-2022-02-preview` has 603 operations from 3 API versions: `2018-10-01`, `2021-05-01`, `2022-02-01-preview`. Use crate feature `package-2022-02-preview` to enable. The operations will be in the `package_2022_02_preview` module.
- `package-2021-08` has 549 operations from 2 API versions: `2018-10-01`, `2021-08-01`. Use crate feature `package-2021-08` to enable. The operations will be in the `package_2021_08` module.
- `package-2021-05-preview` has 603 operations from 3 API versions: `2018-10-01`, `2021-05-01`, `2021-05-01-preview`. Use crate feature `package-2021-05-preview` to enable. The operations will be in the `package_2021_05_preview` module.
- `package-2021-05` has 540 operations from 2 API versions: `2018-10-01`, `2021-05-01`. Use crate feature `package-2021-05` to enable. The operations will be in the `package_2021_05` module.
- `package-2021-03` has 529 operations from 2 API versions: `2018-10-01`, `2021-03-01`. Use crate feature `package-2021-03` to enable. The operations will be in the `package_2021_03` module.
- `package-2021-02` has 527 operations from 2 API versions: `2018-10-01`, `2021-02-01`. Use crate feature `package-2021-02` to enable. The operations will be in the `package_2021_02` module.
- `package-2020-11` has 522 operations from 2 API versions: `2018-10-01`, `2020-11-01`. Use crate feature `package-2020-11` to enable. The operations will be in the `package_2020_11` module.
- `package-2021-02-preview-only` has 65 operations from 1 API versions: `2021-02-01-preview`. Use crate feature `package-2021-02-preview-only` to enable. The operations will be in the `package_2021_02_preview_only` module.
- `package-2021-02-preview` has 594 operations from 3 API versions: `2018-10-01`, `2021-02-01-preview`, `2021-03-01`. Use crate feature `package-2021-02-preview` to enable. The operations will be in the `package_2021_02_preview` module.
- `package-2021-03-preview` has 533 operations from 3 API versions: `2018-10-01`, `2021-02-01`, `2021-03-01-preview`. Use crate feature `package-2021-03-preview` to enable. The operations will be in the `package_2021_03_preview` module.
- `package-2020-08` has 519 operations from 2 API versions: `2018-10-01`, `2020-08-01`. Use crate feature `package-2020-08` to enable. The operations will be in the `package_2020_08` module.
- `package-2020-07` has 513 operations from 2 API versions: `2018-10-01`, `2020-07-01`. Use crate feature `package-2020-07` to enable. The operations will be in the `package_2020_07` module.
- `package-2020-06` has 505 operations from 2 API versions: `2018-10-01`, `2020-06-01`. Use crate feature `package-2020-06` to enable. The operations will be in the `package_2020_06` module.
- `package-2020-05` has 485 operations from 2 API versions: `2018-10-01`, `2020-05-01`. Use crate feature `package-2020-05` to enable. The operations will be in the `package_2020_05` module.
- `package-2020-04` has 462 operations from 2 API versions: `2018-10-01`, `2020-04-01`. Use crate feature `package-2020-04` to enable. The operations will be in the `package_2020_04` module.
- `package-2020-03` has 456 operations from 2 API versions: `2018-10-01`, `2020-03-01`. Use crate feature `package-2020-03` to enable. The operations will be in the `package_2020_03` module.
- `package-2019-12` has 440 operations from 2 API versions: `2018-10-01`, `2019-12-01`. Use crate feature `package-2019-12` to enable. The operations will be in the `package_2019_12` module.
- `package-2019-11` has 434 operations from 2 API versions: `2018-10-01`, `2019-11-01`. Use crate feature `package-2019-11` to enable. The operations will be in the `package_2019_11` module.
- `package-2019-09` has 428 operations from 2 API versions: `2018-10-01`, `2019-09-01`. Use crate feature `package-2019-09` to enable. The operations will be in the `package_2019_09` module.
- `package-2019-08` has 415 operations from 2 API versions: `2018-10-01`, `2019-08-01`. Use crate feature `package-2019-08` to enable. The operations will be in the `package_2019_08` module.
- `package-2019-07` has 408 operations from 2 API versions: `2018-10-01`, `2019-07-01`. Use crate feature `package-2019-07` to enable. The operations will be in the `package_2019_07` module.
- `package-2019-06` has 394 operations from 2 API versions: `2017-03-30`, `2019-06-01`. Use crate feature `package-2019-06` to enable. The operations will be in the `package_2019_06` module.
- `package-2019-04` has 376 operations from 2 API versions: `2017-03-30`, `2019-04-01`. Use crate feature `package-2019-04` to enable. The operations will be in the `package_2019_04` module.
- `package-2019-02` has 354 operations from 2 API versions: `2017-03-30`, `2019-02-01`. Use crate feature `package-2019-02` to enable. The operations will be in the `package_2019_02` module.
- `package-2018-12` has 345 operations from 2 API versions: `2017-03-30`, `2018-12-01`. Use crate feature `package-2018-12` to enable. The operations will be in the `package_2018_12` module.
- `package-2018-12-only` has 332 operations from 1 API versions: `2018-12-01`. Use crate feature `package-2018-12-only` to enable. The operations will be in the `package_2018_12_only` module.
- `package-2018-11` has 337 operations from 2 API versions: `2017-03-30`, `2018-11-01`. Use crate feature `package-2018-11` to enable. The operations will be in the `package_2018_11` module.
- `package-2018-10` has 328 operations from 2 API versions: `2017-03-30`, `2018-10-01`. Use crate feature `package-2018-10` to enable. The operations will be in the `package_2018_10` module.
- `package-2018-08` has 327 operations from 2 API versions: `2017-03-30`, `2018-08-01`. Use crate feature `package-2018-08` to enable. The operations will be in the `package_2018_08` module.
- `package-2018-07` has 269 operations from 2 API versions: `2017-03-30`, `2018-07-01`. Use crate feature `package-2018-07` to enable. The operations will be in the `package_2018_07` module.
- `package-2018-06` has 254 operations from 2 API versions: `2017-03-30`, `2018-06-01`. Use crate feature `package-2018-06` to enable. The operations will be in the `package_2018_06` module.
- `package-2018-04` has 252 operations from 2 API versions: `2017-03-30`, `2018-04-01`. Use crate feature `package-2018-04` to enable. The operations will be in the `package_2018_04` module.
- `package-2018-02` has 216 operations from 2 API versions: `2017-03-30`, `2018-02-01`. Use crate feature `package-2018-02` to enable. The operations will be in the `package_2018_02` module.
- `package-2018-01` has 194 operations from 2 API versions: `2017-03-30`, `2018-01-01`. Use crate feature `package-2018-01` to enable. The operations will be in the `package_2018_01` module.
- `package-2018-01-only` has 186 operations from 1 API versions: `2018-01-01`. Use crate feature `package-2018-01-only` to enable. The operations will be in the `package_2018_01_only` module.
- `package-2017-11` has 194 operations from 2 API versions: `2017-03-30`, `2017-11-01`. Use crate feature `package-2017-11` to enable. The operations will be in the `package_2017_11` module.
- `package-2017-11-only` has 186 operations from 1 API versions: `2017-11-01`. Use crate feature `package-2017-11-only` to enable. The operations will be in the `package_2017_11_only` module.
- `package-2017-10` has 194 operations from 2 API versions: `2017-03-30`, `2017-10-01`. Use crate feature `package-2017-10` to enable. The operations will be in the `package_2017_10` module.
- `package-2017-10-only` has 186 operations from 1 API versions: `2017-10-01`. Use crate feature `package-2017-10-only` to enable. The operations will be in the `package_2017_10_only` module.
- `package-2017-09` has 187 operations from 2 API versions: `2017-03-30`, `2017-09-01`. Use crate feature `package-2017-09` to enable. The operations will be in the `package_2017_09` module.
- `package-2017-09-only` has 179 operations from 1 API versions: `2017-09-01`. Use crate feature `package-2017-09-only` to enable. The operations will be in the `package_2017_09_only` module.
- `package-2017-08` has 163 operations from 2 API versions: `2017-03-30`, `2017-08-01`. Use crate feature `package-2017-08` to enable. The operations will be in the `package_2017_08` module.
- `package-2017-06` has 162 operations from 2 API versions: `2017-03-30`, `2017-06-01`. Use crate feature `package-2017-06` to enable. The operations will be in the `package_2017_06` module.
- `package-2017-03` has 138 operations from 2 API versions: `2017-03-01`, `2017-03-30`. Use crate feature `package-2017-03` to enable. The operations will be in the `package_2017_03` module.
- `package-2017-03-only` has 132 operations from 1 API versions: `2017-03-01`. Use crate feature `package-2017-03-only` to enable. The operations will be in the `package_2017_03_only` module.
- `package-2017-03-30-only` has 8 operations from 2 API versions: `2017-03-30`, `2017-09-01`. Use crate feature `package-2017-03-30-only` to enable. The operations will be in the `package_2017_03_30_only` module.
- `package-2016-12` has 132 operations from 1 API versions: `2016-12-01`. Use crate feature `package-2016-12` to enable. The operations will be in the `package_2016_12` module.
- `package-2016-09` has 120 operations from 1 API versions: `2016-09-01`. Use crate feature `package-2016-09` to enable. The operations will be in the `package_2016_09` module.
- `package-2016-06` has 97 operations from 1 API versions: `2016-06-01`. Use crate feature `package-2016-06` to enable. The operations will be in the `package_2016_06` module.
- `package-2016-03` has 90 operations from 1 API versions: `2016-03-30`. Use crate feature `package-2016-03` to enable. The operations will be in the `package_2016_03` module.
- `package-2015-06split` has 88 operations from 1 API versions: `2015-06-15`. Use crate feature `package-2015-06split` to enable. The operations will be in the `package_2015_06split` module.
- `package-2015-05-preview` has 87 operations from 1 API versions: `2015-05-01-preview`. Use crate feature `package-2015-05-preview` to enable. The operations will be in the `package_2015_05_preview` module.
- `profile-hybrid-2020-09-01` has 112 operations from 1 API versions: `2018-11-01`. Use crate feature `profile-hybrid-2020-09-01` to enable. The operations will be in the `profile_hybrid_2020_09_01` module.
